summaryrefslogtreecommitdiff
path: root/src/lib/video_content.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib/video_content.cc')
-rw-r--r--src/lib/video_content.cc7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/lib/video_content.cc b/src/lib/video_content.cc
index 99471edc1..f9de6aa21 100644
--- a/src/lib/video_content.cc
+++ b/src/lib/video_content.cc
@@ -17,9 +17,10 @@
*/
+#include <iomanip>
#include <libcxml/cxml.h>
#include "video_content.h"
-#include "video_decoder.h"
+#include "video_examiner.h"
#include "ratio.h"
#include "i18n.h"
@@ -99,9 +100,9 @@ VideoContent::as_xml (xmlpp::Node* node) const
}
void
-VideoContent::take_from_video_decoder (shared_ptr<VideoDecoder> d)
+VideoContent::take_from_video_examiner (shared_ptr<VideoExaminer> d)
{
/* These decoder calls could call other content methods which take a lock on the mutex */
libdcp::Size const vs = d->video_size ();
float const vfr = d->video_frame_rate ();
@@ -99,9 +100,9 @@ VideoContent::as_xml (xmlpp::Node* node) const
{
- /* These decoder calls could call other content methods which take a lock on the mutex */
+ /* These examiner calls could call other content methods which take a lock on the mutex */
libdcp::Size const vs = d->video_size ();
float const vfr = d->video_frame_rate ();